"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AssertionError = void 0;
const error_stack_parser_1 = __importDefault(require("error-stack-parser"));
/**
 * Assertion error containing optional info about actual / expected value which
 * can be used by test runners like Mocha to pretty print.
 */
class AssertionError extends Error {
    actual;
    expected;
    constructor(options) {
        const message = options.message;
        super(message);
        this.name = 'AssertionError';
        this.actual = options.actual;
        this.expected = options.expected;
        this.stack = `${this.message}\n${options.stack}`;
    }
    static getLocation(name) {
        const error = new Error('message');
        let cleaned;
        let parsed;
        return {
            file: () => {
                cleaned = cleaned ?? getCleanStack(error);
                parsed = parsed ?? error_stack_parser_1.default.parse({ stack: cleaned });
                return parsed[0]?.fileName;
            },
            stack: () => {
                cleaned = cleaned ?? getCleanStack(error);
                parsed = parsed ?? error_stack_parser_1.default.parse({ stack: cleaned });
                return formatStack(name, parsed);
            },
        };
    }
}
exports.AssertionError = AssertionError;
function getCleanStack(error) {
    const lines = error.stack?.split('\n') ?? [];
    if (lines[0]?.startsWith('Error: message')) {
        return lines.slice(5).join('\n');
    }
    if (lines[0]?.includes('AssertionError') && lines[2]?.includes('^')) {
        // in esbuild-register context is added to the stack trace
        return lines.slice(9).join('\n');
    }
    return error.stack ?? '';
}
function formatStack(name, stack) {
    return stack
        .map((frame, i) => {
        let file = frame.fileName;
        if (file !== undefined && frame.lineNumber !== undefined) {
            file += `:${frame.lineNumber}`;
            if (frame.columnNumber !== undefined) {
                file += `:${frame.columnNumber}`;
            }
        }
        if (i === 0) {
            return file === undefined
                ? `    at ${name}`
                : `    at ${name} (${file})`;
        }
        return frame.source;
    })
        .join('\n');
}
//# sourceMappingURL=AssertionError.js.map