declare module '../../expect.js' {
    interface Matchers {
        /**
         * Matches objects for which a given key exists. Optionally checks the
         * property value.
         *
         * @param key - The expected property key.
         * @param value - (optional) The expected property value.
         *
         * @example
         * ```ts
         * const events = await getLatestEvents({ limit: 3 })
         * expect(events).toEqual([
         *   expect.property('pending', true),
         *   expect.property('finalizedAt'),
         *   expect.property('finalizedAt'),
         * ])
         * ```
         */
        property(key: string, value?: unknown): never;
    }
}
export declare function property(key: string, ...values: unknown[]): (value: unknown) => boolean;
//# sourceMappingURL=property.d.ts.map