"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toBeA = void 0;
const expect_js_1 = require("../../expect.js");
const index_js_1 = require("../../format/index.js");
const a_js_1 = require("../../matchers/basic/a.js");
(0, expect_js_1.registerValidator)('toBeA', toBeA);
function toBeA(control, type) {
    const actualInline = (0, index_js_1.formatCompact)(control.actual);
    const typeInline = getTypeName(type);
    control.assert({
        success: (0, a_js_1.a)(type)(control.actual),
        reason: `The value ${actualInline} is not ${typeInline}, but it was expected to be ${typeInline}.`,
        negatedReason: `The value ${actualInline} is ${typeInline}, but it was expected not to be ${typeInline}.`,
    });
}
exports.toBeA = toBeA;
function getTypeName(type) {
    if (type === String) {
        return 'a string';
    }
    if (type === Number) {
        return 'a number';
    }
    if (type === Boolean) {
        return 'a boolean';
    }
    if (type === BigInt) {
        return 'a bigint';
    }
    if (type === Function) {
        return 'a function';
    }
    if (type === Object) {
        return 'an object';
    }
    if (type === Symbol) {
        return 'a symbol';
    }
    if (type === Array) {
        return 'an array';
    }
    if (typeof type === 'function') {
        return `an instance of ${type.name}`;
    }
    return `an instance of ${(0, index_js_1.formatCompact)(type)}`;
}
//# sourceMappingURL=toBeA.js.map