import type { Control } from '../../Control.js';
declare module '../../expect.js' {
    interface Validators<T> {
        /**
         * Asserts that a number is less the target value.
         *
         * Works for both numbers and bigints.
         *
         * If you want to match a nested value, use the matcher
         * `expect.lessThan(target)` instead.
         *
         * @param target - The target value to compare to.
         *
         * @example
         * ```ts
         * expect(50_000n).toBeLessThan(100_000n)
         *
         * expect(1337n).not.toBeLessThan(1337n)
         * expect(0xdeadbeef).not.toBeLessThan(0xcafebabe)
         * ```
         */
        toBeLessThan(this: Validators<number | bigint>, target: number | bigint): void;
    }
}
export declare function toBeLessThan(control: Control, target: number | bigint): void;
//# sourceMappingURL=toBeLessThan.d.ts.map