import type { Control } from '../../Control.js';
declare module '../../expect.js' {
    interface Validators<T> {
        /**
         * Asserts that a number is less than or equal to the target value.
         *
         * Works for both numbers and bigints.
         *
         * If you want to match a nested value, use the matcher
         * `expect.lessThanOrEqual(target)` instead.
         *
         * @param target - The target value to compare to.
         *
         * @example
         * ```ts
         * expect(50_000n).toBeLessThanOrEqual(100_000n)
         * expect(1337n).toBeLessThanOrEqual(1337n)
         *
         * expect(0xdeadbeef).not.toBeLessThanOrEqual(0xcafebabe)
         * ```
         */
        toBeLessThanOrEqual(this: Validators<number | bigint>, target: number | bigint): void;
    }
}
export declare function toBeLessThanOrEqual(control: Control, target: number | bigint): void;
//# sourceMappingURL=toBeLessThanOrEqual.d.ts.map