import type { Control } from '../../Control.js';
declare module '../../expect.js' {
    interface Validators<T> {
        /**
         * Asserts that a value is referentially equal to the expected value.
         *
         * This validator shouldn't be used for primitives or deep equality checks.
         * Use `toEqual` instead.
         *
         * @param expected - The expected value.
         *
         * @example
         * ```ts
         * const vector = { x: 5, y: 7 }
         * expect(vector).toExactlyEqual(vector)
         *
         * expect(vector).not.toExactlyEqual({ x: 5, y: 7 })
         * ```
         */
        toExactlyEqual(this: Validators<object>, expected: unknown): void;
    }
}
export declare function toExactlyEqual(control: Control, expected: unknown): void;
//# sourceMappingURL=toExactlyEqual.d.ts.map