"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toThrow = void 0;
const expect_js_1 = require("../../expect.js");
const index_js_1 = require("../../format/index.js");
const errors_js_1 = require("./errors.js");
(0, expect_js_1.registerValidator)('toThrow', toThrow);
function toThrow(control, 
// biome-ignore lint/suspicious/noExplicitAny: any is required here
errorClassOrMessage, message) {
    if (typeof control.actual !== 'function') {
        const actualInline = (0, index_js_1.formatCompact)(control.actual);
        control.fail({
            reason: `The value ${actualInline} is not a function, but it was expected to be a function.`,
        });
        return;
    }
    const fn = control.actual;
    const { didThrow, error, result } = (0, errors_js_1.captureError)(() => fn());
    if (result instanceof Promise) {
        const replacement = errorClassOrMessage !== undefined ? 'toBeRejectedWith' : 'toBeRejected';
        control.fail({
            reason: `The function call returned a promise. To make this assertion work with async functions replace toThrow with ${replacement} and add await.`,
        });
    }
    if (!didThrow) {
        control.assert({
            success: false,
            reason: 'The function call did not throw an error, but it was expected to.',
            negatedReason: '',
        });
        return;
    }
    (0, errors_js_1.processError)(control, error, 'The function call threw', errorClassOrMessage, message);
}
exports.toThrow = toThrow;
//# sourceMappingURL=toThrow.js.map