"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSnapshot = exports.resetSnapshotCache = void 0;
const node_fs_1 = require("node:fs");
const node_path_1 = __importDefault(require("node:path"));
const format_js_1 = require("./format.js");
const counters = new Map();
const snapshots = new Map();
function resetSnapshotCache() {
    counters.clear();
    snapshots.clear();
}
exports.resetSnapshotCache = resetSnapshotCache;
function getSnapshot(controlFileName, context, mode) {
    const filePath = context.test?.file ?? controlFileName;
    if (!filePath) {
        throw new TypeError('Invalid test context. Cannot determine test file path.');
    }
    const file = node_path_1.default.join(node_path_1.default.dirname(filePath), `${node_path_1.default.basename(filePath)}.snapshot`);
    const testName = getTestName(context);
    if (!testName) {
        throw new TypeError('Invalid test context. Cannot determine test name.');
    }
    const counter = counters.get(file) ?? new Map();
    counters.set(file, counter);
    const count = counter.get(testName) ?? 1;
    counter.set(testName, count + 1);
    const name = `${testName} ${count}`;
    let content = snapshots.get(file);
    if (!content || mode === 'all') {
        try {
            content = (0, format_js_1.parseSnapshot)((0, node_fs_1.readFileSync)(file, 'utf8'));
        }
        catch { }
    }
    content = content ?? {};
    snapshots.set(file, content);
    const expected = content[name];
    return {
        file,
        name,
        content,
        expected: typeof expected === 'string' ? expected : undefined,
    };
}
exports.getSnapshot = getSnapshot;
function getTestName(context) {
    const name = context.test?.fullTitle();
    if (name) {
        return name;
    }
    if (context.__test__ !== undefined) {
        const parts = [context.__test__];
        if (context.__suite__) {
            parts.unshift(context.__suite__);
        }
        return parts.join(' ');
    }
}
//# sourceMappingURL=getSnapshot.js.map