import { Control } from './Control.js';
import { formatCompact } from './format/index.js';
export class Matcher {
    representation;
    check;
    constructor(representation, check) {
        this.representation = representation;
        this.check = check;
    }
    toString() {
        return this.representation;
    }
}
class Expectation {
    _value;
    _negated = false;
    constructor(_value) {
        this._value = _value;
    }
    get not() {
        if (this._negated) {
            throw new TypeError('Cannot apply .not modifier twice.');
        }
        this._negated = true;
        return this;
    }
    _getControl(name) {
        const functionName = this._negated
            ? `expect().not.${name}`
            : `expect().${name}`;
        return new Control({
            name: functionName,
            actual: this._value,
            isNegated: this._negated,
        });
    }
}
export function registerValidator(name, 
// biome-ignore lint/suspicious/noExplicitAny: any is required here
validator) {
    // biome-ignore lint/suspicious/noExplicitAny: any is required here
    function execute(...args) {
        return validator(this._getControl(name), ...args);
    }
    Object.defineProperty(execute, 'name', { value: name, writable: false });
    Reflect.set(Expectation.prototype, name, execute);
}
const rawExpect = function expect(value) {
    return new Expectation(value);
};
// biome-ignore lint/suspicious/noExplicitAny: any is required here
const matchers = Object.create(null);
// biome-ignore lint/suspicious/noExplicitAny: any is required here
export function registerMatcher(name, check, format) {
    Reflect.set(matchers, name, (...args) => {
        const representation = format
            ? format(...args)
            : `${name}(${args.map((x) => formatCompact(x)).join(', ')})`;
        return new Matcher(representation, check(...args));
    });
}
export const expect = new Proxy(rawExpect, {
    get(target, name) {
        // we need this, because otherwise we cannot override length
        return Reflect.get(matchers, name) ?? Reflect.get(target, name);
    },
});
//# sourceMappingURL=expect.js.map