import type { Control } from '../../Control.js';
import type { MockFunction } from '../../mocks/index.js';
declare module '../../expect.js' {
    interface Validators<T> {
        /**
         * Asserts that the mock function was called enough so that all the
         * specified one time overrides were used.
         *
         * If no one time overrides were specified, this will always pass.
         *
         * @example
         * ```ts
         * import { expect, mockFn } from 'earl'
         *
         * const fn = mockFn().returnsOnce(420).returnsOnce(69)
         * expect(fn).not.toHaveBeenExhausted()
         * fn() // returns 420
         * fn() // returns 69
         * expect(fn).toHaveBeenExhausted()
         * ```
         */
        toHaveBeenExhausted(this: Validators<MockFunction<any[], any>>): void;
    }
}
export declare function toHaveBeenExhausted(control: Control): void;
//# sourceMappingURL=toHaveBeenExhausted.d.ts.map