import type { Control } from '../../Control.js';
declare module '../../expect.js' {
    interface Validators<T> {
        /**
         * Asserts that a number is greater than or equal to the target value.
         *
         * Works for both numbers and bigints.
         *
         * If you want to match a nested value, use the matcher
         * `expect.greaterThanOrEqual(target)` instead.
         *
         * @param target - The target value to compare to.
         *
         * @example
         * ```ts
         * expect(100_000n).toBeGreaterThanOrEqual(50_000n)
         * expect(1337n).toBeGreaterThanOrEqual(1337n)
         *
         * expect(0xcafebabe).not.toBeGreaterThanOrEqual(0xdeadbeef)
         * ```
         */
        toBeGreaterThanOrEqual(this: Validators<number | bigint>, target: number | bigint): void;
    }
}
export declare function toBeGreaterThanOrEqual(control: Control, target: number | bigint): void;
//# sourceMappingURL=toBeGreaterThanOrEqual.d.ts.map