import type { Control } from '../../Control.js';
import { type Subset } from '../../matchers/objects/subset.js';
declare module '../../expect.js' {
    interface Validators<T> {
        /**
         * Asserts that an object contains the given key value pairs.
         *
         * If you want to match a nested value, use the matcher
         * `expect.subset(subset)` instead.
         *
         * @param subset - The expected key-value pairs that the object has.
         *
         * @example
         * ```ts
         * const response = await api.get('/users/me')
         * expect(response).toHaveSubset({
         *   success: expect.a(Boolean),
         *   data: expect.subset({
         *     name: 'John Doe',
         *     age: 42,
         *   }),
         * })
         * ```
         */
        toHaveSubset(this: Validators<object>, subset: Subset): void;
    }
}
export declare function toHaveSubset(control: Control, expected: Subset): void;
//# sourceMappingURL=toHaveSubset.d.ts.map